@@ -3,6 +3,7 @@ from django.db.models.fields import NOT_PROVIDED
 from django.db.models.manager import Manager
 
 from . import widgets
+from .exceptions import FieldError
 
 
 class Field:
@@ -17,7 +18,7 @@ class Field:
         this field in the export.
 
     :param widget: Defines a widget that will be used to represent this
-        field's data in the export.
+        field's data in the export, or transform the value during import.
 
     :param readonly: A Boolean which defines if this field will be ignored
         during import.
@@ -27,11 +28,17 @@ class Field:
         not return an adequate value.
 
     :param saves_null_values: Controls whether null values are saved on the object
+    :param dehydrate_method: Lets you choose your own method for dehydration rather
+        than using `dehydrate_{field_name}` syntax.
+    :param m2m_add: changes save of this field to add the values, if they do not exist,
+        to a ManyToMany field instead of setting all values.  Only useful if field is
+        a ManyToMany field.
     """
     empty_values = [None, '']
 
     def __init__(self, attribute=None, column_name=None, widget=None,
-                 default=NOT_PROVIDED, readonly=False, saves_null_values=True):
+                 default=NOT_PROVIDED, readonly=False, saves_null_values=True,
+                 dehydrate_method=None, m2m_add=False):
         self.attribute = attribute
         self.default = default
         self.column_name = column_name
@@ -40,6 +47,8 @@ class Field:
         self.widget = widget
         self.readonly = readonly
         self.saves_null_values = saves_null_values
+        self.dehydrate_method = dehydrate_method
+        self.m2m_add = m2m_add
 
     def __repr__(self):
         """
@@ -112,7 +121,10 @@ class Field:
                 if not is_m2m:
                     setattr(obj, attrs[-1], cleaned)
                 else:
-                    getattr(obj, attrs[-1]).set(cleaned)
+                    if self.m2m_add:
+                        getattr(obj, attrs[-1]).add(*cleaned)
+                    else:
+                        getattr(obj, attrs[-1]).set(cleaned)
 
     def export(self, obj):
         """
@@ -123,3 +135,15 @@ class Field:
         if value is None:
             return ""
         return self.widget.render(value, obj)
+
+    def get_dehydrate_method(self, field_name=None):
+        """
+        Returns method name to be used for dehydration of the field.
+        Defaults to `dehydrate_{field_name}`
+        """
+        DEFAULT_DEHYDRATE_METHOD_PREFIX = "dehydrate_"
+
+        if not self.dehydrate_method and not field_name:
+            raise FieldError("Both dehydrate_method and field_name are not supplied.")
+
+        return self.dehydrate_method or DEFAULT_DEHYDRATE_METHOD_PREFIX + field_name
