@@ -1,5 +1,7 @@
+import logging
 import warnings
 
+from django.conf import settings
 from django.http import HttpResponse
 from django.utils.timezone import now
 from django.views.generic.edit import FormView
@@ -9,6 +11,8 @@ from .forms import ExportForm
 from .resources import modelresource_factory
 from .signals import post_export
 
+logger = logging.getLogger(__name__)
+
 
 class BaseImportExportMixin:
     formats = base_formats.DEFAULT_FORMATS
@@ -89,6 +93,33 @@ class BaseImportMixin(BaseImportExportMixin):
 
 class BaseExportMixin(BaseImportExportMixin):
     model = None
+    escape_exported_data = False
+    escape_html = False
+    escape_formulae = False
+
+    @property
+    def should_escape_output(self):
+        if hasattr(settings, 'IMPORT_EXPORT_ESCAPE_OUTPUT_ON_EXPORT'):
+            warnings.warn(
+                "IMPORT_EXPORT_ESCAPE_OUTPUT_ON_EXPORT will be deprecated in a future release. "
+                "Refer to docs for new attributes.",
+                DeprecationWarning,
+            )
+        return getattr(settings, 'IMPORT_EXPORT_ESCAPE_OUTPUT_ON_EXPORT', self.escape_exported_data)
+
+    @property
+    def should_escape_html(self):
+        v = getattr(settings, 'IMPORT_EXPORT_ESCAPE_HTML_ON_EXPORT', self.escape_html)
+        if v is True:
+            logger.debug('IMPORT_EXPORT_ESCAPE_HTML_ON_EXPORT is enabled')
+        return v
+
+    @property
+    def should_escape_formulae(self):
+        v = getattr(settings, 'IMPORT_EXPORT_ESCAPE_FORMULAE_ON_EXPORT', self.escape_formulae)
+        if v is True:
+            logger.debug('IMPORT_EXPORT_ESCAPE_FORMULAE_ON_EXPORT is enabled')
+        return v
 
     def get_export_formats(self):
         """
@@ -123,7 +154,7 @@ class BaseExportMixin(BaseImportExportMixin):
         export_form = kwargs.pop('export_form', None)
         return self.choose_export_resource_class(export_form)\
             (**self.get_export_resource_kwargs(request, *args, **kwargs))\
-            .export(queryset, *args, **kwargs)
+            .export(*args, queryset=queryset, **kwargs)
 
     def get_export_filename(self, file_format):
         date_str = now().strftime('%Y-%m-%d')
@@ -141,7 +172,7 @@ class ExportViewMixin(BaseExportMixin):
         Returns file_format representation for given queryset.
         """
         data = self.get_data_for_export(self.request, queryset, *args, **kwargs)
-        export_data = file_format.export_data(data)
+        export_data = file_format.export_data(data, escape_output=self.should_escape_output)
         return export_data
 
     def get_context_data(self, **kwargs):
