@@ -1,6 +1,7 @@
 import functools
 import logging
 import traceback
+import warnings
 from collections import OrderedDict
 from copy import deepcopy
 
@@ -17,12 +18,7 @@ from django.core.paginator import Paginator
 from django.db import connections, router
 from django.db.models.fields.related import ForeignObjectRel
 from django.db.models.query import QuerySet
-from django.db.transaction import (
-    TransactionManagementError,
-    savepoint,
-    savepoint_commit,
-    savepoint_rollback,
-)
+from django.db.transaction import TransactionManagementError, set_rollback
 from django.utils.encoding import force_str
 from django.utils.safestring import mark_safe
 
@@ -314,6 +310,7 @@ class Resource(metaclass=DeclarativeMetaclass):
         """
         return Diff
 
+    @classmethod
     def get_db_connection_name(self):
         if self._meta.using_db is None:
             return router.db_for_write(self._meta.model)
@@ -392,7 +389,7 @@ class Resource(metaclass=DeclarativeMetaclass):
         """
         return [f for f in self.fields if f not in self._meta.import_id_fields]
 
-    def bulk_create(self, using_transactions, dry_run, raise_errors, batch_size=None):
+    def bulk_create(self, using_transactions, dry_run, raise_errors, batch_size=None, result=None):
         """
         Creates objects by calling ``bulk_create``.
         """
@@ -403,13 +400,11 @@ class Resource(metaclass=DeclarativeMetaclass):
                 else:
                     self._meta.model.objects.bulk_create(self.create_instances, batch_size=batch_size)
         except Exception as e:
-            logger.exception(e)
-            if raise_errors:
-                raise e
+            self.handle_import_error(result, e, raise_errors)
         finally:
             self.create_instances.clear()
 
-    def bulk_update(self, using_transactions, dry_run, raise_errors, batch_size=None):
+    def bulk_update(self, using_transactions, dry_run, raise_errors, batch_size=None, result=None):
         """
         Updates objects by calling ``bulk_update``.
         """
@@ -421,13 +416,11 @@ class Resource(metaclass=DeclarativeMetaclass):
                     self._meta.model.objects.bulk_update(self.update_instances, self.get_bulk_update_fields(),
                                                          batch_size=batch_size)
         except Exception as e:
-            logger.exception(e)
-            if raise_errors:
-                raise e
+            self.handle_import_error(result, e, raise_errors)
         finally:
             self.update_instances.clear()
 
-    def bulk_delete(self, using_transactions, dry_run, raise_errors):
+    def bulk_delete(self, using_transactions, dry_run, raise_errors, result=None):
         """
         Deletes objects by filtering on a list of instances to be deleted,
         then calling ``delete()`` on the entire queryset.
@@ -440,9 +433,7 @@ class Resource(metaclass=DeclarativeMetaclass):
                     delete_ids = [o.pk for o in self.delete_instances]
                     self._meta.model.objects.filter(pk__in=delete_ids).delete()
         except Exception as e:
-            logger.exception(e)
-            if raise_errors:
-                raise e
+            self.handle_import_error(result, e, raise_errors)
         finally:
             self.delete_instances.clear()
 
@@ -636,7 +627,7 @@ class Resource(metaclass=DeclarativeMetaclass):
                 # m2m instance values are taken from the 'row' because they
                 # have not been written to the 'instance' at this point
                 instance_values = list(field.clean(row))
-                original_values = list(field.get_value(original).all())
+                original_values = list() if original.pk is None else list(field.get_value(original).all())
                 if len(instance_values) != len(original_values):
                     return False
 
@@ -683,7 +674,15 @@ class Resource(metaclass=DeclarativeMetaclass):
         """
         pass
 
-    def import_row(self, row, instance_loader, using_transactions=True, dry_run=False, raise_errors=False, **kwargs):
+    def handle_import_error(self, result, error, raise_errors=False):
+        logger.debug(error, exc_info=error)
+        if result:
+            tb_info = traceback.format_exc()
+            result.append_base_error(self.get_error_result_class()(error, tb_info))
+        if raise_errors:
+            raise
+
+    def import_row(self, row, instance_loader, using_transactions=True, dry_run=False, raise_errors=None, **kwargs):
         """
         Imports data from ``tablib.Dataset``. Refer to :doc:`import_workflow`
         for a more complete description of the whole import process.
@@ -698,6 +697,12 @@ class Resource(metaclass=DeclarativeMetaclass):
         :param dry_run: If ``dry_run`` is set, or error occurs, transaction
             will be rolled back.
         """
+        if raise_errors is not None:
+            warnings.warn(
+                "raise_errors argument is deprecated and will be removed in a future release.",
+                category=DeprecationWarning
+            )
+
         skip_diff = self._meta.skip_diff
         row_result = self.get_row_result_class()()
         if self._meta.store_row_values:
@@ -762,17 +767,6 @@ class Resource(metaclass=DeclarativeMetaclass):
             tb_info = traceback.format_exc()
             row_result.errors.append(self.get_error_result_class()(e, tb_info, row))
 
-        if self._meta.use_bulk:
-            # persist a batch of rows
-            # because this is a batch, any exceptions are logged and not associated
-            # with a specific row
-            if len(self.create_instances) == self._meta.batch_size:
-                self.bulk_create(using_transactions, dry_run, raise_errors, batch_size=self._meta.batch_size)
-            if len(self.update_instances) == self._meta.batch_size:
-                self.bulk_update(using_transactions, dry_run, raise_errors, batch_size=self._meta.batch_size)
-            if len(self.delete_instances) == self._meta.batch_size:
-                self.bulk_delete(using_transactions, dry_run, raise_errors)
-
         return row_result
 
     def import_data(self, dataset, dry_run=False, raise_errors=False,
@@ -816,32 +810,33 @@ class Resource(metaclass=DeclarativeMetaclass):
             raise ValueError("Batch size must be a positive integer")
 
         with atomic_if_using_transaction(using_transactions, using=db_connection):
-            return self.import_data_inner(
-                dataset, dry_run, raise_errors, using_transactions, collect_failed_rows,
-                rollback_on_validation_errors, **kwargs)
+            result = self.import_data_inner(
+                dataset, dry_run, raise_errors, using_transactions, collect_failed_rows, **kwargs)
+            if using_transactions and (dry_run or result.has_errors() or
+                                       (rollback_on_validation_errors and result.has_validation_errors())):
+                set_rollback(True, using=db_connection)
+            return result
 
     def import_data_inner(
             self, dataset, dry_run, raise_errors, using_transactions,
-            collect_failed_rows, rollback_on_validation_errors=False, **kwargs):
+            collect_failed_rows, rollback_on_validation_errors=None, **kwargs):
+
+        if rollback_on_validation_errors is not None:
+            warnings.warn(
+                "rollback_on_validation_errors argument is deprecated and will be removed in a future release.",
+                category=DeprecationWarning
+            )
+
         result = self.get_result_class()()
         result.diff_headers = self.get_diff_headers()
         result.total_rows = len(dataset)
         db_connection = self.get_db_connection_name()
 
-        if using_transactions:
-            # when transactions are used we want to create/update/delete object
-            # as transaction will be rolled back if dry_run is set
-            sp1 = savepoint(using=db_connection)
-
         try:
             with atomic_if_using_transaction(using_transactions, using=db_connection):
                 self.before_import(dataset, using_transactions, dry_run, **kwargs)
         except Exception as e:
-            logger.debug(e, exc_info=e)
-            tb_info = traceback.format_exc()
-            result.append_base_error(self.get_error_result_class()(e, tb_info))
-            if raise_errors:
-                raise
+            self.handle_import_error(result, e, raise_errors)
 
         instance_loader = self._meta.instance_loader_class(self, dataset)
 
@@ -851,17 +846,33 @@ class Resource(metaclass=DeclarativeMetaclass):
         if collect_failed_rows:
             result.add_dataset_headers(dataset.headers)
 
-        for i, row in enumerate(dataset.dict, 1):
-            with atomic_if_using_transaction(using_transactions, using=db_connection):
+        for i, data_row in enumerate(dataset, 1):
+            row = OrderedDict(zip(dataset.headers, data_row))
+            with atomic_if_using_transaction(using_transactions and not self._meta.use_bulk, using=db_connection):
                 row_result = self.import_row(
                     row,
                     instance_loader,
                     using_transactions=using_transactions,
                     dry_run=dry_run,
                     row_number=i,
-                    raise_errors=raise_errors,
                     **kwargs
                 )
+            if self._meta.use_bulk:
+                # persist a batch of rows
+                # because this is a batch, any exceptions are logged and not associated
+                # with a specific row
+                if len(self.create_instances) == self._meta.batch_size:
+                    with atomic_if_using_transaction(using_transactions, using=db_connection):
+                        self.bulk_create(using_transactions, dry_run, raise_errors,
+                                         batch_size=self._meta.batch_size, result=result)
+                if len(self.update_instances) == self._meta.batch_size:
+                    with atomic_if_using_transaction(using_transactions, using=db_connection):
+                        self.bulk_update(using_transactions, dry_run, raise_errors,
+                                         batch_size=self._meta.batch_size, result=result)
+                if len(self.delete_instances) == self._meta.batch_size:
+                    with atomic_if_using_transaction(using_transactions, using=db_connection):
+                        self.bulk_delete(using_transactions, dry_run, raise_errors, result=result)
+
             result.increment_row_result_total(row_result)
 
             if row_result.errors:
@@ -882,27 +893,15 @@ class Resource(metaclass=DeclarativeMetaclass):
         if self._meta.use_bulk:
             # bulk persist any instances which are still pending
             with atomic_if_using_transaction(using_transactions, using=db_connection):
-                self.bulk_create(using_transactions, dry_run, raise_errors)
-                self.bulk_update(using_transactions, dry_run, raise_errors)
-                self.bulk_delete(using_transactions, dry_run, raise_errors)
+                self.bulk_create(using_transactions, dry_run, raise_errors, result=result)
+                self.bulk_update(using_transactions, dry_run, raise_errors, result=result)
+                self.bulk_delete(using_transactions, dry_run, raise_errors, result=result)
 
         try:
             with atomic_if_using_transaction(using_transactions, using=db_connection):
                 self.after_import(dataset, result, using_transactions, dry_run, **kwargs)
         except Exception as e:
-            logger.debug(e, exc_info=e)
-            tb_info = traceback.format_exc()
-            result.append_base_error(self.get_error_result_class()(e, tb_info))
-            if raise_errors:
-                raise
-
-        if using_transactions:
-            if dry_run or \
-                    result.has_errors() or \
-                    (rollback_on_validation_errors and result.has_validation_errors()):
-                savepoint_rollback(sp1, using=db_connection)
-            else:
-                savepoint_commit(sp1, using=db_connection)
+            self.handle_import_error(result, e, raise_errors)
 
         return result
 
@@ -924,7 +923,9 @@ class Resource(metaclass=DeclarativeMetaclass):
 
     def export_field(self, field, obj):
         field_name = self.get_field_name(field)
-        method = getattr(self, 'dehydrate_%s' % field_name, None)
+        dehydrate_method = field.get_dehydrate_method(field_name)
+
+        method = getattr(self, dehydrate_method, None)
         if method is not None:
             return method(obj)
         return field.export(obj)
@@ -965,10 +966,22 @@ class Resource(metaclass=DeclarativeMetaclass):
         else:
             yield from queryset.iterator(chunk_size=self.get_chunk_size())
 
-    def export(self, queryset=None, *args, **kwargs):
+    def export(self, *args, queryset=None, **kwargs):
         """
         Exports a resource.
+        :returns: Dataset object.
         """
+        if len(args) == 1 and (isinstance(args[0], QuerySet) or isinstance(args[0], list)):
+            # issue 1565: definition of export() was incorrect
+            # if queryset is being passed, it must be as the first arg or named parameter
+            # this logic is included for backwards compatibility:
+            # if the method is being called without a named parameter, add a warning
+            # this check should be removed in a future release
+            warnings.warn(
+                "'queryset' must be supplied as a named parameter",
+                category=DeprecationWarning
+            )
+            queryset = args[0]
 
         self.before_export(queryset, *args, **kwargs)
 
