@@ -148,7 +148,12 @@ class DateTimeWidgetTest(TestCase):
     @override_settings(USE_TZ=True, TIME_ZONE='Europe/Ljubljana')
     def test_clean_returns_tz_aware_datetime_when_naive_datetime_passed(self):
         # issue 1165
-        target_dt = timezone.make_aware(self.datetime, pytz.timezone('Europe/Ljubljana'))
+        if django.VERSION >= (5, 0):
+            from zoneinfo import ZoneInfo
+            tz = ZoneInfo("Europe/Ljubljana")
+        else:
+            tz = pytz.timezone('Europe/Ljubljana')
+        target_dt = timezone.make_aware(self.datetime, tz)
         self.assertEqual(target_dt, self.widget.clean(self.datetime))
 
     @override_settings(USE_TZ=True, TIME_ZONE='Europe/Ljubljana')
@@ -224,6 +229,7 @@ class TimeWidgetTest(TestCase):
     def test_clean_returns_time_when_time_passed(self):
         self.assertEqual(self.time, self.widget.clean(self.time))
 
+
 class DurationWidgetTest(TestCase):
 
     def setUp(self):
@@ -254,11 +260,45 @@ class DurationWidgetTest(TestCase):
             self.widget.clean("x")
 
 
+class NumberWidgetTest(TestCase):
+
+    def setUp(self):
+        self.value = 11.111
+        self.widget = widgets.NumberWidget()
+        self.widget_coerce_to_string = widgets.NumberWidget(coerce_to_string=True)
+
+    def test_is_empty_value_is_none(self):
+        self.assertTrue(self.widget.is_empty(None))
+
+    def test_is_empty_value_is_empty_string(self):
+        self.assertTrue(self.widget.is_empty(""))
+
+    def test_is_empty_value_is_whitespace(self):
+        self.assertTrue(self.widget.is_empty(" "))
+
+    def test_is_empty_value_is_zero(self):
+        self.assertFalse(self.widget.is_empty(0))
+
+    def test_render(self):
+        self.assertEqual(self.widget.render(self.value), self.value)
+
+    @skipUnless(django.VERSION[0] < 4, f"skipping django {django.VERSION} version specific test")
+    @override_settings(LANGUAGE_CODE='fr-fr', USE_L10N=True)
+    def test_locale_render_coerce_to_string(self):
+        self.assertEqual(self.widget_coerce_to_string.render(self.value), "11,111")
+
+    @skipUnless(django.VERSION[0] >= 4, f"skipping django {django.VERSION} version specific test")
+    @override_settings(LANGUAGE_CODE='fr-fr')
+    def test_locale_render_coerce_to_string(self):
+        self.assertEqual(self.widget_coerce_to_string.render(self.value), "11,111")
+
+
 class FloatWidgetTest(TestCase):
 
     def setUp(self):
         self.value = 11.111
         self.widget = widgets.FloatWidget()
+        self.widget_coerce_to_string = widgets.FloatWidget(coerce_to_string=True)
 
     def test_clean(self):
         self.assertEqual(self.widget.clean(11.111), self.value)
@@ -275,12 +315,24 @@ class FloatWidgetTest(TestCase):
         self.assertEqual(self.widget.clean(" "), None)
         self.assertEqual(self.widget.clean("\r\n\t"), None)
 
+    @skipUnless(django.VERSION[0] < 4, f"skipping django {django.VERSION} version specific test")
+    @override_settings(LANGUAGE_CODE='fr-fr', USE_L10N=True)
+    def test_locale_render_coerce_to_string(self):
+        self.assertEqual(self.widget_coerce_to_string.render(self.value), "11,111")
+
+    @skipUnless(django.VERSION[0] >= 4, f"skipping django {django.VERSION} version specific test")
+    @override_settings(LANGUAGE_CODE='fr-fr')
+    def test_locale_render_coerce_to_string(self):
+        self.assertEqual(self.widget_coerce_to_string.render(self.value), "11,111")
+
+
 
 class DecimalWidgetTest(TestCase):
 
     def setUp(self):
         self.value = Decimal("11.111")
         self.widget = widgets.DecimalWidget()
+        self.widget_coerce_to_string = widgets.DecimalWidget(coerce_to_string=True)
 
     def test_clean(self):
         self.assertEqual(self.widget.clean("11.111"), self.value)
@@ -298,6 +350,16 @@ class DecimalWidgetTest(TestCase):
         self.assertEqual(self.widget.clean(" "), None)
         self.assertEqual(self.widget.clean("\r\n\t"), None)
 
+    @skipUnless(django.VERSION[0] < 4, f"skipping django {django.VERSION} version specific test")
+    @override_settings(LANGUAGE_CODE='fr-fr', USE_L10N=True)
+    def test_locale_render_coerce_to_string(self):
+        self.assertEqual(self.widget_coerce_to_string.render(self.value), "11,111")
+
+    @skipUnless(django.VERSION[0] >= 4, f"skipping django {django.VERSION} version specific test")
+    @override_settings(LANGUAGE_CODE='fr-fr')
+    def test_locale_render_coerce_to_string(self):
+        self.assertEqual(self.widget_coerce_to_string.render(self.value), "11,111")
+
 
 class IntegerWidgetTest(TestCase):
 
@@ -305,6 +367,7 @@ class IntegerWidgetTest(TestCase):
         self.value = 0
         self.widget = widgets.IntegerWidget()
         self.bigintvalue = 163371428940853127
+        self.widget_coerce_to_string = widgets.IntegerWidget(coerce_to_string=True)
 
     def test_clean_integer_zero(self):
         self.assertEqual(self.widget.clean(0), self.value)
@@ -320,6 +383,16 @@ class IntegerWidgetTest(TestCase):
         self.assertEqual(self.widget.clean(""), None)
         self.assertEqual(self.widget.clean(" "), None)
         self.assertEqual(self.widget.clean("\n\t\r"), None)
+    
+    @skipUnless(django.VERSION[0] < 4, f"skipping django {django.VERSION} version specific test")
+    @override_settings(LANGUAGE_CODE='fr-fr', USE_L10N=True)
+    def test_locale_render_lt_django4(self):
+        self.assertEqual(self.widget_coerce_to_string.render(self.value), "0")
+
+    @skipUnless(django.VERSION[0] >= 4, f"skipping django {django.VERSION} version specific test")
+    @override_settings(LANGUAGE_CODE='fr-fr')
+    def test_locale_render_gte_django4(self):
+        self.assertEqual(self.widget_coerce_to_string.render(self.value), "0") 
 
 
 class ForeignKeyWidgetTest(TestCase):
@@ -413,6 +486,7 @@ class ForeignKeyWidgetTest(TestCase):
             self.natural_key_book_widget.render(self.book), json.dumps(self.book.natural_key())
         )
 
+
 class ManyToManyWidget(TestCase):
 
     def setUp(self):
