@@ -111,3 +111,5 @@ LOGGING = {
 USE_TZ = False
 if django.VERSION >= (4, 1):
     FORM_RENDERER = "django.forms.renderers.DjangoDivFormRenderer"
+if django.VERSION >= (5, 0):
+    FORM_RENDERER = "django.forms.renderers.DjangoTemplates"
